MonthlyCalendarCoordinator | django_cradmin API Document

    import {MonthlyCalendarCoordinator} from 'django_cradmin/scripts/django_cradmin/utilities/Calendar.js'

public class | source

# MonthlyCalendarCoordinator

Coordinates the common calendar data for a month-view.

## Constructor Summary

Public Constructor
public | constructor(objectPattern: {"calendarCoordinator": *, "yearselectValues": *, "hourselectValues": *, "minuteselectValues": *, "yearFormat": *, "monthFormat": *, "dayOfMonthSelectFormat": *, "dayOfMonthTableCellFormat": *, "hourFormat": *, "minuteFormat": *}) |

## Member Summary

Public Members
public | calendarCoordinator: * |
public | calendarMonth: * |
public | currentHourObject: * |
public | currentMinuteObject: * |
public | currentMonthObject: * |
public | currentYearObject: * |
public | dayOfMonthSelectFormat: * |
public | dayOfMonthTableCellFormat: * |
public | dayobjects: * |
public | hourFormat: * |
public | hourselectConfig: * |
public | hourselectValues: * |
public | minuteFormat: * |
public | minuteselectConfig: * |
public | minuteselectValues: * |
public | monthFormat: * |
public | monthselectConfig: * |
public | yearFormat: * |
public | yearselectConfig: * |
public | yearselectValues: * |

## Method Summary

Public Methods
public | getDayOfMonthLabelForTableCell(calendarDay: *): * |
public | getLastFocusedMomentObject(): * |
public | handleCalendarDayChange(calendarDay: *): * |
public | handleCurrentDayObjectChange(): * |
public | handleCurrentHourChange(): * |
public | handleCurrentMinuteChange(): * |
public | handleCurrentMonthChange(): * |
public | handleCurrentYearChange(): * |
public | handleDayChange(momentObject: *): * |
public | handleFocusOnCalendarDay(calendarDay: *): * |
public | setToToday(): * |

## Public Constructors

### public constructor(objectPattern: {"calendarCoordinator": *, "yearselectValues": *, "hourselectValues": *, "minuteselectValues": *, "yearFormat": *, "monthFormat": *, "dayOfMonthSelectFormat": *, "dayOfMonthTableCellFormat": *, "hourFormat": *, "minuteFormat": *}) source

#### Params:

Name | Type | Attribute | Description
objectPattern | {"calendarCoordinator": *, "yearselectValues": *, "hourselectValues": *, "minuteselectValues": *, "yearFormat": *, "monthFormat": *, "dayOfMonthSelectFormat": *, "dayOfMonthTableCellFormat": *, "hourFormat": *, "minuteFormat": *} | default: {"calendarCoordinator":null,"yearselectValues":null,"hourselectValues":null,"minuteselectValues":null,"yearFormat":null,"monthFormat":null,"dayOfMonthSelectFormat":null,"dayOfMonthTableCellFormat":null,"hourFormat":null,"minuteFormat":null} |

## Public Members

### public calendarCoordinator: * source

### public calendarMonth: * source

### public currentHourObject: * source

### public currentMinuteObject: * source

### public currentMonthObject: * source

### public currentYearObject: * source

### public dayOfMonthSelectFormat: * source

### public dayOfMonthTableCellFormat: * source

### public dayobjects: * source

### public hourFormat: * source

### public hourselectConfig: * source

### public hourselectValues: * source

### public minuteFormat: * source

### public minuteselectConfig: * source

### public minuteselectValues: * source

### public monthFormat: * source

### public monthselectConfig: * source

### public yearFormat: * source

### public yearselectConfig: * source

### public yearselectValues: * source

## Public Methods

### public getDayOfMonthLabelForTableCell(calendarDay: *): * source

#### Params:

Name | Type | Attribute | Description
calendarDay | * |  |

#### Return:

*

### public getLastFocusedMomentObject(): * source

#### Return:

*

### public handleCalendarDayChange(calendarDay: *): * source

#### Params:

Name | Type | Attribute | Description
calendarDay | * |  |

#### Return:

*

### public handleCurrentDayObjectChange(): * source

#### Return:

*

### public handleCurrentHourChange(): * source

#### Return:

*

### public handleCurrentMinuteChange(): * source

#### Return:

*

### public handleCurrentMonthChange(): * source

#### Return:

*

### public handleCurrentYearChange(): * source

#### Return:

*

### public handleDayChange(momentObject: *): * source

#### Params:

Name | Type | Attribute | Description
momentObject | * |  |

#### Return:

*

### public handleFocusOnCalendarDay(calendarDay: *): * source

#### Params:

Name | Type | Attribute | Description
calendarDay | * |  |

#### Return:

*

### public setToToday(): * source

#### Return:

*